/**
 *  轻提示方法，将antd-mobile中的Toast组件进行封装：
 *  自动关闭时间封装成2秒；
 *  关闭后无回调方法；
 *  使用场景：
 *  可以用来显示不会打断用户操作的内容，适合用于页面转场、数据交互的等场景中。
 */
import { Toast as AntdToast } from 'antd-mobile';

export default class Toast {
  duration = 2;

  /*
   * @function:成功提示
   * content:提示内容
   * */
  static success(content) {
    AntdToast.success(content ? content : '操作成功', this.duration, null, false)
  }

  /*
   * @function:失败提示
   * content:提示内容
   * */
  static fail(content) {
    AntdToast.fail(content ? content : '加载失败', this.duration, null, false)
  }

  /*
   * @function:信息提示
   * content:提示内容
   * */
  static info(content) {
    AntdToast.info(content, this.duration, null, false)
  }

  /*
   * @function:加载中提示
   * content:提示内容
   * mask:是否显示透明蒙层，防止触摸穿透
   * */
  static loading(content, mask) {
    AntdToast.loading(content ? content : '加载中', 0, null, mask ? mask : false)
  }

  /*
   * @function: 网络失败提示
   * content:提示内容
   * */
  static offline(content) {
    AntdToast.offline(content ? content : '网络异常，请检查网络环境', this.duration, null, false)
  }

  /*
   *@function:隐藏提示
   * */
  static hide() {
    AntdToast.hide();
  }
}
